@@ -1,59 +1,52 @@
+# -*- coding: utf-8 -*-
+from AccessControl import ClassSecurityInfo
+from AccessControl.SecurityManagement import getSecurityManager
+from Acquisition import aq_get
+from DateTime import DateTime
+from Globals import InitializeClass
+from OFS.Cache import Cacheable
+from pas.plugins.sqlalchemy import model
+from Products.CMFCore.utils import getToolByName
+from Products.PageTemplates.PageTemplateFile import PageTemplateFile
+from Products.PlonePAS.interfaces.capabilities import IAssignRoleCapability
+from Products.PlonePAS.interfaces.capabilities import IDeleteCapability
+from Products.PlonePAS.interfaces.capabilities import IGroupCapability
+from Products.PlonePAS.interfaces.capabilities import IPasswordSetCapability
+from Products.PlonePAS.interfaces.group import IGroupIntrospection
+from Products.PlonePAS.interfaces.group import IGroupManagement
+from Products.PlonePAS.interfaces.plugins import IMutablePropertiesPlugin
+from Products.PlonePAS.interfaces.plugins import IUserManagement
+from Products.PlonePAS.interfaces.propertysheets import IMutablePropertySheet
+from Products.PlonePAS.plugins.group import PloneGroup
+from Products.PluggableAuthService.events import PropertiesUpdated
+from Products.PluggableAuthService.interfaces import plugins as pasplugins
+from Products.PluggableAuthService.permissions import ManageGroups
+from Products.PluggableAuthService.permissions import ManageUsers
+from Products.PluggableAuthService.permissions import SetOwnPassword
+from Products.PluggableAuthService.plugins.BasePlugin import BasePlugin
+from Products.PluggableAuthService.UserPropertySheet import UserPropertySheet
+from Products.PluggableAuthService.utils import createViewName
+from sqlalchemy import sql
+from z3c.saconfig import named_scoped_session
+from zope.component.interfaces import ComponentLookupError
+from zope.dottedname.resolve import resolve
+from zope.event import notify
+from zope.interface import implementer
 import datetime
 import logging
 import sqlalchemy as rdb
-from sqlalchemy import sql
+import time
 import traceback
 
-from zope.dottedname.resolve import resolve
-from zope.event import notify
-from Acquisition import aq_get
-from AccessControl import ClassSecurityInfo
-from AccessControl.SecurityManagement import getSecurityManager
-from Globals import InitializeClass
-from Products.CMFCore.utils import getToolByName
-from Products.PageTemplates.PageTemplateFile import PageTemplateFile
-from Products.PluggableAuthService.utils import classImplements
-from Products.PluggableAuthService.plugins.BasePlugin import BasePlugin
-from Products.PluggableAuthService.permissions import ManageUsers, ManageGroups
-from Products.PluggableAuthService.permissions import SetOwnPassword
-from Products.PluggableAuthService.utils import createViewName
-from Products.PluggableAuthService.events import PropertiesUpdated
-from OFS.Cache import Cacheable
-from DateTime import DateTime
-
-# Pluggable Auth Service
-from Products.PluggableAuthService.interfaces.plugins import (
-    IUserAdderPlugin,
-    IRolesPlugin,
-    IGroupsPlugin,
-    IPropertiesPlugin,
-    IAuthenticationPlugin,
-    IUserEnumerationPlugin,
-    IRoleAssignerPlugin,
-    IGroupEnumerationPlugin
-    )
-
-# PlonePAS
-from Products.PlonePAS.interfaces.plugins import IUserManagement
-from Products.PlonePAS.interfaces.capabilities import IDeleteCapability
-from Products.PlonePAS.interfaces.capabilities import IPasswordSetCapability
-from Products.PlonePAS.interfaces.capabilities import IAssignRoleCapability
-from Products.PlonePAS.interfaces.capabilities import IGroupCapability
-from Products.PlonePAS.interfaces.plugins import IMutablePropertiesPlugin
-from Products.PlonePAS.interfaces.group import IGroupIntrospection
-from Products.PlonePAS.interfaces.group import IGroupManagement
-from Products.PlonePAS.sheet import MutablePropertySheet
-from Products.PlonePAS.plugins.group import PloneGroup
-
-from pas.plugins.sqlalchemy import model
-from z3c.saconfig import named_scoped_session
-
 Session = named_scoped_session("pas.plugins.sqlalchemy")
 
 logger = logging.getLogger("pas.plugins.sqlalchemy")
 
-manage_addSqlalchemyPlugin = PageTemplateFile("templates/addPlugin",
-        globals(), __name__="manage_addPlugin")
+manage_addSqlalchemyPlugin = PageTemplateFile(
+    "templates/addPlugin",
+    globals(),
+    __name__="manage_addPlugin"
+)
 
 
 def addSqlalchemyPlugin(self, id, title="", user_model=None,
@@ -66,9 +59,10 @@ def addSqlalchemyPlugin(self, id, title="", user_model=None,
     self._setObject(p.getId(), p)
 
     if REQUEST is not None:
-        REQUEST.response.redirect("%s/manage_workspace"
-                "?manage_tabs_message=SQLAlchemy+plugin+added." %
-                self.absolute_url())
+        REQUEST.response.redirect(
+            "%s/manage_workspace?manage_tabs_message=SQLAlchemy+plugin+"
+            "added." % self.absolute_url()
+        )
 
 
 def safeencode(v):
@@ -83,12 +77,31 @@ def safedecode(v):
     return v
 
 
+_V_ERROR_MARKER = '_v_pas.plugins.sqlalchemy_errored'
+
+
 def graceful_recovery(default=None, log_args=True):
     def decorator(func):
         def wrapper(*args, **kwargs):
             try:
                 value = func(*args, **kwargs)
-            except rdb.exc.SQLAlchemyError, e:
+            except ComponentLookupError as e:
+                # XXX this may mask different ComponentLookupErrors as well!
+                try:
+                    exc_str = str(e)
+                except Exception as e:
+                    exc_str = "<%s at 0x%x>" % (e.__class__.__name__, id(e))
+                # only log once every 3 seconds
+                if getattr(args[0], _V_ERROR_MARKER, 0) < time.time() - 3:
+                    setattr(args[0], _V_ERROR_MARKER, time.time())
+                    logger.critical(
+                        "Apparently we haven't yet configured a z3c.saconfig "
+                        "connection. This may mask other "
+                        "ComponentLookupErrors as well!\n{0:s}".format(exc_str)
+                    )
+
+                return default
+            except rdb.exc.SQLAlchemyError as e:
                 if log_args is False:
                     args = ()
                     kwargs = {}
@@ -97,17 +110,17 @@ def graceful_recovery(default=None, log_args=True):
 
                 try:
                     exc_str = str(e)
-                except:
+                except Exception as e:
                     exc_str = "<%s at 0x%x>" % (e.__class__.__name__, id(e))
 
                 logger.critical(
                     "caught SQL-exception: "
                     "%s (in method ``%s``; arguments were %s)\n\n%s" % (
-                    exc_str,
-                    func.__name__, ", ".join(
-                        [repr(arg) for arg in args] +
-                        ["%s=%s" % (name, repr(value))
-                         for (name, value) in kwargs.items()]
+                        exc_str,
+                        func.__name__, ", ".join(
+                            [repr(arg) for arg in args] +
+                            ["%s=%s" % (name, repr(value))
+                             for (name, value) in kwargs.items()]
                         ), formatted_tb))
                 return default
             return value
@@ -115,26 +128,75 @@ def graceful_recovery(default=None, log_args=True):
     return decorator
 
 
+@implementer(IMutablePropertySheet)
+class MutablePropertySheet(UserPropertySheet):
+    """Mutable property sheet that persists changes back via plugin."""
+
+    def __init__(self, plugin, **kwargs):
+        UserPropertySheet.__init__(self, plugin.id, **kwargs)
+        self._plugin = plugin
+
+    def __getitem__(self, key):
+        return self.getProperty(key)
+
+    def __iter__(self):
+        return self.propertyIds()
+
+    def get(self, key, default):
+        return self.getProperty(key, default)
+
+    def canWriteProperty(self, object, id):
+        return True
+
+    def setProperty(self, object, id, value):
+        self._properties[id] = value
+        self._plugin.doSetProperty(object, id, value)
+
+    def setProperties(self, object, mapping):
+        self._properties.update(mapping)
+        self._plugin.setPropertiesForUser(object, self)
+
+
+@implementer(
+    pasplugins.IAuthenticationPlugin,
+    pasplugins.IUserEnumerationPlugin,
+    pasplugins.IUserAdderPlugin,
+    IUserManagement,
+    IDeleteCapability,
+    IPasswordSetCapability,
+    pasplugins.IRolesPlugin,
+    pasplugins.IRoleAssignerPlugin,
+    IAssignRoleCapability,
+    IGroupCapability,
+    pasplugins.IPropertiesPlugin,
+    IMutablePropertiesPlugin,
+    pasplugins.IGroupsPlugin,
+    pasplugins.IGroupEnumerationPlugin,
+    IGroupIntrospection,
+    IGroupManagement
+)
 class Plugin(BasePlugin, Cacheable):
     meta_type = 'SQLAlchemy user/group/prop manager'
     security = ClassSecurityInfo()
+    manage_options = BasePlugin.manage_options + Cacheable.manage_options
 
     _properties = BasePlugin._properties + (
-            {'id'    : 'user_model',
-             'label' : 'SQLAlchemy User model (dotted path)',
-             'type'  : 'string',
-             'mode'  : 'w',
-            },
-            {'id'    : 'principal_model',
-             'label' : 'SQLAlchemy Principal model (dotted path)',
-             'type'  : 'string',
-             'mode'  : 'w',
-            },
-            {'id'    : 'group_model',
-             'label' : 'SQLAlchemy Group model (dotted path)',
-             'type'  : 'string',
-             'mode'  : 'w',
-            })
+        {'id': 'user_model',
+         'label': 'SQLAlchemy User model (dotted path)',
+         'type': 'string',
+         'mode': 'w',
+         },
+        {'id': 'principal_model',
+         'label': 'SQLAlchemy Principal model (dotted path)',
+         'type': 'string',
+         'mode': 'w',
+         },
+        {'id': 'group_model',
+         'label': 'SQLAlchemy Group model (dotted path)',
+         'type': 'string',
+         'mode': 'w',
+         }
+    )
 
     user_model = "pas.plugins.sqlalchemy.model.User"
     principal_model = "pas.plugins.sqlalchemy.model.Principal"
@@ -151,7 +213,7 @@ class Plugin(BasePlugin, Cacheable):
         if group_model:
             self.group_model = group_model
 
-    security.declarePrivate('invalidateCacheForChangedUser')
+    @security.private
     def invalidateCacheForChangedUser(self, user_id):
         pass
 
@@ -161,7 +223,7 @@ class Plugin(BasePlugin, Cacheable):
         if cls is None:
             try:
                 cls = self._v_principal_class = resolve(self.principal_model)
-            except ImportError, e:
+            except ImportError as e:
                 logger.error("Unable to import user model: %s", e)
                 cls = self._v_principal_class = model.Principal
         return cls
@@ -172,7 +234,7 @@ class Plugin(BasePlugin, Cacheable):
         if cls is None:
             try:
                 cls = self._v_user_class = resolve(self.user_model)
-            except ImportError, e:
+            except ImportError as e:
                 logger.error("Unable to import user model: %s", e)
                 cls = self._v_user_class = model.User
         return cls
@@ -183,7 +245,7 @@ class Plugin(BasePlugin, Cacheable):
         if cls is None:
             try:
                 cls = self._v_group_class = resolve(self.group_model)
-            except ImportError, e:
+            except ImportError as e:
                 logger.error("Unable to import group model: %s", e)
                 cls = self._v_group_class = model.Group
         return cls
@@ -192,7 +254,7 @@ class Plugin(BasePlugin, Cacheable):
     # IUserManagement implementation
     #
 
-    security.declarePrivate('doChangeUser')
+    @security.private
     @graceful_recovery()
     def doChangeUser(self, principal_id, password, **kw):
         # userSetPassword in PlonePAS expects a RuntimeError when a
@@ -203,10 +265,10 @@ class Plugin(BasePlugin, Cacheable):
         if user is None:
             raise RuntimeError(
                 "User does not exist: zope_id=%s" % principal_id
-                )
+            )
         user.set_password(password)
 
-    security.declarePrivate('doDeleteUser')
+    @security.private
     @graceful_recovery()
     def doDeleteUser(self, login):
         session = Session()
@@ -219,20 +281,18 @@ class Plugin(BasePlugin, Cacheable):
     #
     # IPasswordSetCapability implementation
     #
-    security.declarePublic('allowPasswordSet')
+    @security.public
     @graceful_recovery(False)
     def allowPasswordSet(self, userid):
         session = Session()
         user = session.query(self.user_class).filter_by(zope_id=userid).first()
-        if user is not None:
-            return True
-        return False
+        return user is not None
 
     #
     # IAuthenticationPlugin implementation
     #
 
-    security.declarePrivate('authenticateCredentials')
+    @security.private
     @graceful_recovery(log_args=False)
     def authenticateCredentials(self, credentials):
         login = credentials.get('login')
@@ -253,13 +313,14 @@ class Plugin(BasePlugin, Cacheable):
     def _enumerate(self, cls, exact_match, sort_by, max_results, criteria):
         """Helper method for enumerateUsers and enumerateGroups.
         """
+
         if exact_match and not ("login" in criteria or "id" in criteria):
             return ()
 
         view_name = createViewName(
             'enumerate%s' % cls.__name__,
             criteria.get("id", None) or criteria.get("login", None)
-            )
+        )
         cachekey = {
             '_exact_match': exact_match,
             '_sort_by': sort_by,
@@ -313,7 +374,7 @@ class Plugin(BasePlugin, Cacheable):
 
         return values
 
-    security.declarePrivate('enumerateUsers')
+    @security.private
     @graceful_recovery(())
     def enumerateUsers(self, id=None, login=None, exact_match=False,
                        sort_by=None, max_results=None, **kw):
@@ -329,13 +390,12 @@ class Plugin(BasePlugin, Cacheable):
 
         return self._enumerate(
             self.user_class, exact_match, sort_by, max_results, kw
-            )
-
+        )
 
     #
     # IUserAdderPlugin implementation
     #
-    security.declarePrivate('doAddUser')
+    @security.private
     def doAddUser(self, login, password):
         try:
             self.addUser(login, login, password)
@@ -343,7 +403,7 @@ class Plugin(BasePlugin, Cacheable):
             return False
         return True
 
-    security.declarePrivate('addUser')
+    @security.private
     @graceful_recovery(log_args=False)
     def addUser(self, user_id, login_name, password):
         session = Session()
@@ -351,7 +411,7 @@ class Plugin(BasePlugin, Cacheable):
         new_user.set_password(password)
         session.add(new_user)
 
-    security.declarePrivate('removeUser')
+    @security.private
     @graceful_recovery()
     def removeUser(self, user_id):  # raises keyerror
         session = Session()
@@ -362,10 +422,10 @@ class Plugin(BasePlugin, Cacheable):
 
         session.delete(user)
 
-   #
+    #
     # Allow users to change their own login name and password.
     #
-    security.declareProtected(SetOwnPassword, 'getOwnUserInfo')
+    @security.protected(SetOwnPassword)
     def getOwnUserInfo(self):
         """Return current user's info."""
 
@@ -375,11 +435,11 @@ class Plugin(BasePlugin, Cacheable):
     def allowRoleAssign(self, principal_id, role_id):
         return True
 
-    security.declarePrivate('doRemoveRoleFromPrincipal')
+    @security.private
     def doRemoveRoleFromPrincipal(self, principal_id, role):
         return self.removeRoleFromPrincipal(role, principal_id)
 
-    security.declareProtected(ManageUsers, 'removeRoleFromPrincipal')
+    @security.protected(ManageUsers)
     def removeRoleFromPrincipal(self, role_id, principal_id):
         """ Remove a role from a principal (user or group).
 
@@ -396,20 +456,19 @@ class Plugin(BasePlugin, Cacheable):
 
             view_name = createViewName(
                 'getRolesForPrincipal-IgnDirFalse-IgnGrpFalse', principal_id
-                )
+            )
             self.ZCacheable_invalidate(view_name)
             return True
 
         return False
 
-    security.declarePrivate('doRemoveRolesFromPrincipal')
+    @security.private
     def doRemoveRolesFromPrincipal(self, roles, principal_id):
         principal = self._get_principal_by_id(principal_id)
         for role in roles:
             principal.roles.remove(role)
 
-
-    security.declareProtected(ManageUsers, 'assignRolesToPrincipal')
+    @security.protected(ManageUsers)
     def assignRolesToPrincipal(self, roles, principal_id):
         """Assign a specific set of roles, and only those roles, to a
         principal.
@@ -424,7 +483,7 @@ class Plugin(BasePlugin, Cacheable):
         # remove actual roles that are not in the roles parameter
         actual_roles = self.getRolesForPrincipal(
             principal_id, ignore_groups=True
-            )
+        )
 
         self.doRemoveRolesFromPrincipal(
             [role for role in actual_roles if role not in roles], principal_id)
@@ -434,17 +493,17 @@ class Plugin(BasePlugin, Cacheable):
             if role not in ignored_roles:
                 self.doAssignRoleToPrincipal(
                     principal_id, role, invalidate_cache=False
-                    )
+                )
 
         view_name = createViewName(
             'getRolesForPrincipal-IgnDirFalse-IgnGrpFalse', principal_id
-            )
+        )
 
         self.ZCacheable_invalidate(view_name)
 
-    security.declarePrivate('doAssignRoleToPrincipal')
-    def doAssignRoleToPrincipal(self, principal_id, role, invalidate_cache=True):
-
+    @security.private
+    def doAssignRoleToPrincipal(
+            self, principal_id, role, invalidate_cache=True):
         """ Create a principal/role association in a Role Manager
 
         o Return a Boolean indicating whether the role was assigned or not
@@ -459,15 +518,15 @@ class Plugin(BasePlugin, Cacheable):
         if invalidate_cache:
             view_name = createViewName(
                 'getRolesForPrincipal-IgnDirFalse-IgnGrpFalse', principal_id
-                )
+            )
             self.ZCacheable_invalidate(view_name)
 
         return True
 
-    security.declarePrivate('getRolesForPrincipal')
+    @security.private
     @graceful_recovery(())
-    def getRolesForPrincipal(self, principal, request=None, ignore_groups=False):
-
+    def getRolesForPrincipal(
+            self, principal, request=None, ignore_groups=False):
         """ principal -> ( role_1, ... role_N )
 
         o Return a sequence of role names which the principal has.
@@ -494,7 +553,7 @@ class Plugin(BasePlugin, Cacheable):
         # '__ignore_direct_roles__' = True should be pushed in the request.
         __ignore_direct_roles__ = request and request.get(
             '__ignore_direct_roles__', False
-            )
+        )
 
         # Some services may need the real roles of an user but **not**
         # the ones he got through his groups. In this case, the
@@ -502,12 +561,12 @@ class Plugin(BasePlugin, Cacheable):
         # in the request.
         __ignore_group_roles__ = (
             request and request.get('__ignore_group_roles__', False)
-            ) or ignore_groups
+        ) or ignore_groups
 
         method_name = 'getRolesForPrincipal-IgnDir%s-IgnGrp%s' % (
             str(__ignore_direct_roles__),
             str(__ignore_group_roles__)
-            )
+        )
 
         view_name = createViewName(method_name, principal_id)
         cached_info = self.ZCacheable_get(view_name)
@@ -551,7 +610,7 @@ class Plugin(BasePlugin, Cacheable):
                 schema = [(elt['id'], elt['type']) for elt in mdschema]
         return schema
 
-    security.declarePrivate('getPropertiesForUser')
+    @security.private
     @graceful_recovery()
     def getPropertiesForUser(self, user, request=None):
         """Get property values for a user or group.
@@ -561,44 +620,46 @@ class Plugin(BasePlugin, Cacheable):
 
         view_name = createViewName('getPropertiesForUser', user.getId())
         cached_info = self.ZCacheable_get(view_name=view_name)
-        schema = self._getSchema(isGroup)
+        schema = self._getSchema(isGroup) or None
         if cached_info is not None:
-            if schema:
-                return MutablePropertySheet(self.id,
-                             schema=schema, **cached_info)
-            else:
-                return MutablePropertySheet(self.id, **cached_info)
-        session = Session()
-        query = session.query(self.principal_class).filter_by(
-            zope_id=user.getId()
+            return MutablePropertySheet(
+                self, schema=schema, **cached_info
             )
 
+        session = Session()
+        column_name = dict(self.principal_class._properties).get(
+            'zope_id',  # map zope_id
+            'zope_id'   # if not mapped fall back to 'zope_id'
+        )
+        filter_data = {column_name: user.getId()}
+        query = session.query(self.principal_class).filter_by(**filter_data)
         principal = query.first()
         if principal is None:
             # XXX: Should we cache a negative result?
-            return {}
+            # return MutablePropertySheet(self, schema=schema)
+            # return none if user not exists
+            return None
 
         data = {}
         for (zope_attr, sql_attr) in principal._properties:
             value = getattr(principal, sql_attr)
 
             if isinstance(value, datetime.datetime) or \
-                   isinstance(value, datetime.date):
+                    isinstance(value, datetime.date):
                 value = DateTime(value.isoformat())
             data[zope_attr] = value
-
         if data:
             self.ZCacheable_set(data, view_name=view_name)
             data.pop('id', None)
-            if schema:
-                sheet = MutablePropertySheet(self.id,
-                            schema=schema, **data)
-            else:
-                sheet = MutablePropertySheet(self.id, **data)
-            return sheet
+            return MutablePropertySheet(self, schema=schema, **data)
 
-    security.declarePrivate('doSetProperty')
+    @security.private
     def doSetProperty(self, principal, name, value):
+        username = principal.getId()
+        principal = self._get_principal_by_id(username)
+        if not principal:
+            return
+
         propmap = dict([reversed(r) for r in principal._properties])
         sql_attr = propmap.get(name, None)
         if sql_attr is None:
@@ -612,19 +673,18 @@ class Plugin(BasePlugin, Cacheable):
         # application)
         if isinstance(value, basestring):
             value = safedecode(value)
-            cspec = getattr(principal.__table__.columns, sql_attr).type
+            cspec = getattr(principal.__mapper__.columns, sql_attr).type
             if isinstance(cspec, rdb.String):
                 value = value[:cspec.length]
         setattr(principal, sql_attr, value)
 
-    security.declarePrivate('setPropertiesForUser')
+    @security.private
     @graceful_recovery()
     def setPropertiesForUser(self, user, propertysheet):
-        session = Session()
-        principal = session.query(self.principal_class).\
-                filter_by(zope_id=user.getId()).first()
-
+        username = user.getId()
+        principal = self._get_principal_by_id(username)
         properties = propertysheet.propertyItems()
+
         for name, value in properties:
             self.doSetProperty(principal, name, value)
 
@@ -647,7 +707,7 @@ class Plugin(BasePlugin, Cacheable):
     # IGroupsPlugin implementation
     #
 
-    security.declarePrivate('getGroupsForPrincipal')
+    @security.private
     @graceful_recovery(())
     def getGroupsForPrincipal(self, principal, request=None):
         """ principal -> ( group_1, ... group_N )
@@ -665,7 +725,7 @@ class Plugin(BasePlugin, Cacheable):
 
         session = Session()
         principal = session.query(self.principal_class)\
-                .filter_by(zope_id=principal_id).first()
+            .filter_by(zope_id=principal_id).first()
         if principal is None:
             return ()
 
@@ -675,7 +735,7 @@ class Plugin(BasePlugin, Cacheable):
     # IGroupsEnumeration implementation
     #
 
-    security.declarePrivate('enumerateGroups')
+    @security.private
     @graceful_recovery(())
     def enumerateGroups(self, id=None,
                         exact_match=False,
@@ -728,14 +788,13 @@ class Plugin(BasePlugin, Cacheable):
 
         return self._enumerate(
             self.group_class, exact_match, sort_by, max_results, kw
-            )
-
+        )
 
     ####################
     # IGroupManagement
     ####################
 
-    security.declarePrivate('addGroup')
+    @security.private
     @graceful_recovery(False)
     def addGroup(self, id, **kw):
         """
@@ -752,7 +811,7 @@ class Plugin(BasePlugin, Cacheable):
 
         return True
 
-    security.declareProtected(ManageGroups, 'addPrincipalToGroup')
+    @security.protected(ManageGroups)
     @graceful_recovery(False)
     def addPrincipalToGroup(self, principal_id, group_id):
         """
@@ -767,7 +826,7 @@ class Plugin(BasePlugin, Cacheable):
             return False
 
         principal = session.query(self.principal_class)\
-                .filter_by(zope_id=principal_id).first()
+            .filter_by(zope_id=principal_id).first()
 
         if principal is None:
             return False
@@ -775,7 +834,7 @@ class Plugin(BasePlugin, Cacheable):
         group.members.append(principal)
         return True
 
-    security.declarePrivate('removeGroup')
+    @security.private
     @graceful_recovery(False)
     def removeGroup(self, group_id):
         """
@@ -792,7 +851,7 @@ class Plugin(BasePlugin, Cacheable):
 
         return False
 
-    security.declareProtected(ManageGroups, 'removePrincipalFromGroup')
+    @security.protected(ManageGroups)
     @graceful_recovery(False)
     def removePrincipalFromGroup(self, principal_id, group_id):
         """
@@ -802,9 +861,9 @@ class Plugin(BasePlugin, Cacheable):
         session = Session()
 
         group = session.query(self.group_class)\
-                .filter_by(zope_id=group_id).first()
+            .filter_by(zope_id=group_id).first()
         user = session.query(self.principal_class)\
-                .filter_by(zope_id=principal_id).first()
+            .filter_by(zope_id=principal_id).first()
 
         if group is None or user is None:
             return False
@@ -812,11 +871,11 @@ class Plugin(BasePlugin, Cacheable):
         group.members.remove(user)
         return True
 
-    security.declarePrivate( 'updateGroup' )
+    @security.private
     def updateGroup(self, group_id, title=None, description=None):
         session = Session()
         principal = session.query(self.principal_class).\
-                filter_by(zope_id=group_id).first()
+            filter_by(zope_id=group_id).first()
         if title:
             self.doSetProperty(principal, 'title', title)
         if description:
@@ -829,11 +888,10 @@ class Plugin(BasePlugin, Cacheable):
     #   IDeleteCapability implementation
     #
 
-    security.declarePublic('allowDeletePrincipal')
+    @security.public
     @graceful_recovery(False)
     def allowDeletePrincipal(self, principal_id):
         """True if this plugin can delete a certain principal."""
-
         return self._get_principal_by_id(principal_id) is not None
 
     #
@@ -942,7 +1000,7 @@ class Plugin(BasePlugin, Cacheable):
     # PlonePAS expects plugins implementing IRoleAssignerPlugin to
     # implement addRole. (In addRole in pas).  The method is not
     # specified in the IRoleAssignerPlugin interface, so this is bad.
-    security.declareProtected(ManageUsers, 'addRole')
+    @security.protected(ManageUsers)
     def addRole(self, role_id, title='', description=''):
         # We do not manage roles.
         raise AttributeError
@@ -950,14 +1008,14 @@ class Plugin(BasePlugin, Cacheable):
     def _get_groups_for_principal_from_pas(self, principal):
         plugins = self._getPAS()._getOb('plugins')
 
-        for name, plugin in plugins.listPlugins(IGroupsPlugin):
+        for name, plugin in plugins.listPlugins(pasplugins.IGroupsPlugin):
             groups = plugin.getGroupsForPrincipal(principal)
             if groups:
                 yield groups
 
     def _get_properties_for_user_from_pas(self, principal):
         plugins = self._getPAS()._getOb('plugins')
-        propfinders = plugins.listPlugins(IPropertiesPlugin)
+        propfinders = plugins.listPlugins(pasplugins.IPropertiesPlugin)
         for propfinder_id, propfinder in propfinders:
             data = propfinder.getPropertiesForUser(principal, request=None)
             if data:
@@ -965,7 +1023,7 @@ class Plugin(BasePlugin, Cacheable):
 
     def _get_roles_for_principal_from_pas(self, principal):
         plugins = self._getPAS()._getOb('plugins')
-        rolemakers = plugins.listPlugins(IRolesPlugin)
+        rolemakers = plugins.listPlugins(pasplugins.IRolesPlugin)
 
         for rolemaker_id, rolemaker in rolemakers:
             roles = rolemaker.getRolesForPrincipal(principal, request=None)
@@ -976,27 +1034,8 @@ class Plugin(BasePlugin, Cacheable):
         session = Session()
         query = session.query(self.principal_class).filter_by(
             zope_id=principal_id
-            )
+        )
         return query.first()
 
 
-classImplements(
-    Plugin,
-    IAuthenticationPlugin,
-    IUserEnumerationPlugin,
-    IUserAdderPlugin,
-    IUserManagement,
-    IDeleteCapability,
-    IPasswordSetCapability,
-    IRolesPlugin,
-    IRoleAssignerPlugin,
-    IAssignRoleCapability,
-    IGroupCapability,
-    IPropertiesPlugin,
-    IMutablePropertiesPlugin,
-    IGroupsPlugin,
-    IGroupEnumerationPlugin,
-    IGroupIntrospection,
-    IGroupManagement)
-
 InitializeClass(Plugin)
