@@ -1,16 +1,14 @@
-import plugin
-import model
-
-from z3c.saconfig import named_scoped_session
-Session = named_scoped_session("pas.plugins.sqlalchemy")
+# -*- coding: utf-8 -*-
+from pas.plugins.sqlalchemy import plugin
 
 plugin_name = "sql"
 
 
 def install_pas_plugin(self):
     pas = self.acl_users
-    if not plugin_name in pas.objectIds():
-        manager = plugin.Plugin(plugin_name, "SQLAlchemy user/group/prop store")
+    if plugin_name not in pas.objectIds():
+        manager = plugin.Plugin(
+            plugin_name, "SQLAlchemy user/group/prop store")
         pas._setObject(plugin_name, manager)
         provider = pas[plugin_name]
         provider.manage_activateInterfaces([
@@ -35,16 +33,14 @@ def uninstall_pas_plugin(self):
 
 
 def uninstall(context):
-    if context.readDataFile('marker.txt') is None:
+    if context.readDataFile('pas_plugins_sqlalchemy_uninstall.txt') is None:
         return
     portal = context.getSite()
     uninstall_pas_plugin(portal)
 
 
 def install(context):
-    if context.readDataFile('marker.txt') is None:
+    if context.readDataFile('pas_plugins_sqlalchemy_install.txt') is None:
         return
     portal = context.getSite()
-    session = Session()
-    model.Base.metadata.create_all(session.bind)
     install_pas_plugin(portal)
