@@ -1,26 +1,30 @@
-
+# -*- coding: utf-8 -*-
 # tests from sqlpasplugin ( GPL v2 )
 
 from pas.plugins.sqlalchemy.tests import basetestcase
 from pas.plugins.sqlalchemy.setuphandlers import plugin_name
 from Products.PlonePAS.plugins.group import PloneGroup
 
-class TestGroupManager( basetestcase.BaseTestCase ):
+
+class TestGroupManager(basetestcase.BaseTestCase):
+
     def afterSetUp(self):
         self.group_name = u'gr\xfcppe'
         self.groupname = self.group_name
         self.source_groups = self.getPAS()[plugin_name]
-        self.source_users  = self.getPAS()[plugin_name]
+        self.source_users = self.getPAS()[plugin_name]
 
     def testAddGroup(self):
-        self.source_groups.addGroup( self.group_name )
-        ret = self.source_groups.enumerateGroups( id=self.group_name, exact_match=True )
-        self.assertEqual( len(ret), 1 )
-        self.source_groups.removeGroup( self.group_name )
+        self.source_groups.addGroup(self.group_name)
+        ret = self.source_groups.enumerateGroups(
+            id=self.group_name, exact_match=True)
+        self.assertEqual(len(ret), 1)
+        self.source_groups.removeGroup(self.group_name)
 
-    def testRemoveGroup( self ):
+    def testRemoveGroup(self):
         # Is it empty?
-        ret = self.source_groups.enumerateGroups(id=self.group_name, exact_match=True)
+        ret = self.source_groups.enumerateGroups(
+            id=self.group_name, exact_match=True)
         self.assertEqual(len(ret), 0)
 
         # allowRemove
@@ -29,7 +33,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
 
         # Add one
         self.source_groups.addGroup(self.group_name)
-        ret = self.source_groups.enumerateGroups(id=self.group_name, exact_match=True)
+        ret = self.source_groups.enumerateGroups(
+            id=self.group_name, exact_match=True)
         self.assertEqual(len(ret), 1)
 
         # allowRemove
@@ -38,18 +43,21 @@ class TestGroupManager( basetestcase.BaseTestCase ):
 
         # Delete one
         self.source_groups.removeGroup(self.group_name)
-        ret = self.source_groups.enumerateGroups(id=self.group_name, exact_match=True)
+        ret = self.source_groups.enumerateGroups(
+            id=self.group_name, exact_match=True)
         self.assertEqual(len(ret), 0)
 
     def testMembershipLifecycle(self):
         # Create Group
         self.source_groups.addGroup(self.groupname)
-        ret = self.source_groups.enumerateGroups(id=self.groupname, exact_match=True)
+        ret = self.source_groups.enumerateGroups(
+            id=self.groupname, exact_match=True)
         self.assertEqual(len(ret), 1)
 
         # Create User
         self.source_users.doAddUser(self.username, self.password)
-        ret = self.source_users.enumerateUsers(id=self.username, exact_match=True)
+        ret = self.source_users.enumerateUsers(
+            id=self.username, exact_match=True)
         self.assertEqual(len(ret), 1)
 
         # User should have no memberships
@@ -72,7 +80,6 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         self.source_users.removeUser(self.username)
         self.source_groups.removeGroup(self.groupname)
 
-
     def testEnumerateGroups(self):
         "groupmanager.enumerateGroups()"
         ret = self.source_groups.enumerateGroups()
@@ -85,7 +92,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         self.assertEqual(len(ret), count,
                          "Number added didn't equal the number in the db.")
 
-        ret = self.source_groups.enumerateGroups(id='group_1', exact_match=True)
+        ret = self.source_groups.enumerateGroups(
+            id='group_1', exact_match=True)
         self.assertEqual(len(ret), 1)
 
         ret = self.source_groups.enumerateGroups(max_results=5)
@@ -111,7 +119,7 @@ class TestGroupManager( basetestcase.BaseTestCase ):
 
         # Exact match Multiple Group Test
         ret = self.source_groups.enumerateGroups(
-            id=['group_2','group_3'], exact_match=True)
+            id=['group_2', 'group_3'], exact_match=True)
         self.assertEqual(len(ret), 2,
                          "Failed multi-fetch")
 
@@ -123,10 +131,9 @@ class TestGroupManager( basetestcase.BaseTestCase ):
 
         # Exact Match test
         ret = self.source_groups.enumerateGroups(
-            id=['group_1','group_1'], exact_match=1)
+            id=['group_1', 'group_1'], exact_match=1)
         self.assertEqual(len(ret), 1)
 
-
         ret = self.source_groups.enumerateGroups(max_results=5)
         self.assertEqual(len(ret), 5)
 
@@ -137,7 +144,6 @@ class TestGroupManager( basetestcase.BaseTestCase ):
             groupname = 'group_%i' % x
             self.source_groups.removeGroup(groupname)
 
-
     def testIGroupIntrospection_getGroupById_getGroups(self):
 
         group = self.source_groups.getGroupById(self.groupname)
@@ -151,10 +157,10 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         self.failUnless(isinstance(group, PloneGroup))
 
         # add another group
-        self.source_groups.addGroup(self.groupname+'1')
+        self.source_groups.addGroup(self.groupname + '1')
 
         groups = self.source_groups.getGroups()
-        self.assertEqual(len(groups),2)
+        self.assertEqual(len(groups), 2)
         self.failUnless(isinstance(groups[0], PloneGroup))
         self.failUnless(isinstance(groups[1], PloneGroup))
 
@@ -172,7 +178,7 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         self.assertEqual(len(ret), 1)
 
         # add another group
-        self.source_groups.addGroup(self.groupname+'1')
+        self.source_groups.addGroup(self.groupname + '1')
 
         ret = self.source_groups.getGroupIds()
         self.assertEqual(len(ret), 2)
@@ -187,7 +193,7 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         # Cleanup
         self.source_users.removeUser(self.username)
         self.source_groups.removeGroup(self.groupname)
-        self.source_groups.removeGroup(self.groupname+'1')
+        self.source_groups.removeGroup(self.groupname + '1')
 
     def testIGroupIntrospection_getGroupMembers(self):
         # add group
@@ -199,7 +205,7 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         # add users
         users_number = 3
         for i in range(users_number):
-            username = '%s_%s'%(self.username,i)
+            username = '%s_%s' % (self.username, i)
             self.source_users.doAddUser(username, self.password)
             self.source_groups.addPrincipalToGroup(username, self.groupname)
 
@@ -208,16 +214,16 @@ class TestGroupManager( basetestcase.BaseTestCase ):
 
         # Cleanup
         for i in range(users_number):
-            username = '%s_%s'%(self.username,i)
+            username = '%s_%s' % (self.username, i)
             self.source_users.removeUser(username)
         self.source_groups.removeGroup(self.groupname)
 
-
     def testIGroupCapability(self):
         ret = self.source_groups.allowGroupAdd(self.username, self.groupname)
         self.assertEqual(ret, False)
 
-        ret = self.source_groups.allowGroupRemove(self.username, self.groupname)
+        ret = self.source_groups.allowGroupRemove(
+            self.username, self.groupname)
         self.assertEqual(ret, False)
 
         # add group
@@ -226,7 +232,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         ret = self.source_groups.allowGroupAdd(self.username, self.groupname)
         self.assertEqual(ret, True)
 
-        ret = self.source_groups.allowGroupRemove(self.username, self.groupname)
+        ret = self.source_groups.allowGroupRemove(
+            self.username, self.groupname)
         self.assertEqual(ret, False)
 
         # add user
@@ -235,7 +242,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         ret = self.source_groups.allowGroupAdd(self.username, self.groupname)
         self.assertEqual(ret, True)
 
-        ret = self.source_groups.allowGroupRemove(self.username, self.groupname)
+        ret = self.source_groups.allowGroupRemove(
+            self.username, self.groupname)
         self.assertEqual(ret, False)
 
         self.source_groups.addPrincipalToGroup(self.username, self.groupname)
@@ -243,7 +251,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         ret = self.source_groups.allowGroupAdd(self.username, self.groupname)
         self.assertEqual(ret, False)
 
-        ret = self.source_groups.allowGroupRemove(self.username, self.groupname)
+        ret = self.source_groups.allowGroupRemove(
+            self.username, self.groupname)
         self.assertEqual(ret, True)
 
         # Cleanup
@@ -251,10 +260,8 @@ class TestGroupManager( basetestcase.BaseTestCase ):
         self.source_groups.removeGroup(self.groupname)
 
 
-
-def test_suite( ):
+def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestGroupManager))
     return suite
-
