@@ -1,11 +1,10 @@
-
+# -*- coding: utf-8 -*-
 # tests from sqlpasplugin ( GPL v2 )
-
+from pas.plugins.sqlalchemy.setuphandlers import plugin_name
+from pas.plugins.sqlalchemy.tests import basetestcase
+from pas.plugins.sqlalchemy.tests.basetestcase import TrivialUser
 from Products.PlonePAS.sheet import MutablePropertySheet
 
-from pas.plugins.sqlalchemy.tests import basetestcase
-from pas.plugins.sqlalchemy.setuphandlers import plugin_name
-from pas.plugins.sqlalchemy.tests.basetestcase import TrivialUser
 
 class TestUserManager(basetestcase.BaseTestCase):
 
@@ -34,12 +33,12 @@ class TestUserManager(basetestcase.BaseTestCase):
 
     def testAuthenticateCredentials(self):
         auth = self.plugin.authenticateCredentials({'login': self.username,
-                                                          'password': self.password})
+                                                    'password': self.password})
         self.assertEqual(auth, None)
 
         self.plugin.doAddUser(self.username, self.password)
         auth = self.plugin.authenticateCredentials({'login': self.username,
-                                                          'password': self.password})
+                                                    'password': self.password})
         self.assertEqual(auth, (self.username, self.username))
 
 
@@ -51,8 +50,7 @@ class TestEnumerateUsers(basetestcase.BaseTestCase):
         self.plugin.doAddUser('user_2', 'password')
         self.plugin.doAddUser('foo_user_1', 'password')
         self.plugin.doAddUser('bar', 'password')
-        self.user=TrivialUser('user_1')
-
+        self.user = TrivialUser('user_1')
 
     def testNoIdAndNoLoginNoExact(self):
         ret = self.plugin.enumerateUsers()
@@ -64,25 +62,25 @@ class TestEnumerateUsers(basetestcase.BaseTestCase):
 
     def testReturnFormat(self):
         ret = self.plugin.enumerateUsers(id='user_1', exact_match=True)
-        expected = (dict(login='user_1', id= 'user_1', pluginid=plugin_name),)
-        #self.assertEqual( ret, expected )
+        expected = (dict(login='user_1', id='user_1', pluginid=plugin_name),)
+        # self.assertEqual( ret, expected )
 
         self.assertEqual(len(ret), len(expected))
-        self.assertEqual( ret[0]['login'], expected[0]['login'])
-        self.assertEqual( ret[0]['id'], expected[0]['id'])
-        self.assertEqual( ret[0]['pluginid'], expected[0]['pluginid'])
+        self.assertEqual(ret[0]['login'], expected[0]['login'])
+        self.assertEqual(ret[0]['id'], expected[0]['id'])
+        self.assertEqual(ret[0]['pluginid'], expected[0]['pluginid'])
 
     def testIdStringNoExact(self):
         ret = self.plugin.enumerateUsers(id='user_1')
-        self.assertEqual(len(ret), 2) # user_1, foo_user_1
+        self.assertEqual(len(ret), 2)  # user_1, foo_user_1
 
     def testIdStringNoExactUnicode(self):
         ret = self.plugin.enumerateUsers(id=u'user_1')
-        self.assertEqual(len(ret), 2) # user_1, foo_user_1
+        self.assertEqual(len(ret), 2)  # user_1, foo_user_1
 
     def testIdEqualLogin(self):
         ret = self.plugin.enumerateUsers(id='user_1', login='user_1')
-        self.assertEqual(len(ret), 2) # user_1, foo_user_1
+        self.assertEqual(len(ret), 2)  # user_1, foo_user_1
 
     def testLoginStringExact(self):
         ret = self.plugin.enumerateUsers(login='user', exact_match=True)
@@ -90,23 +88,25 @@ class TestEnumerateUsers(basetestcase.BaseTestCase):
 
     def testLoginStringNoExact(self):
         ret = self.plugin.enumerateUsers(login='user')
-        self.assertEqual(len(ret), 3) # all but bar
+        self.assertEqual(len(ret), 3)  # all but bar
 
     def testLoginListExact(self):
-        ret = self.plugin.enumerateUsers(login=['user_1', '2'], exact_match=True)
-        self.assertEqual(len(ret), 1) # user_1
+        ret = self.plugin.enumerateUsers(
+            login=['user_1', '2'], exact_match=True)
+        self.assertEqual(len(ret), 1)  # user_1
 
     def testLoginListNoExact(self):
         ret = self.plugin.enumerateUsers(login=['user_0', '2'])
-        self.assertEqual(len(ret), 1) # user_2
+        self.assertEqual(len(ret), 1)  # user_2
 
     def testIdListExact(self):
-        ret = self.plugin.enumerateUsers(id=['user_1', 'foo'], exact_match=True)
-        self.assertEqual(len(ret), 1) # user_1
+        ret = self.plugin.enumerateUsers(
+            id=['user_1', 'foo'], exact_match=True)
+        self.assertEqual(len(ret), 1)  # user_1
 
     def testIdListNoExact(self):
         ret = self.plugin.enumerateUsers(id=['user_1', 'foo'])
-        self.assertEqual(len(ret), 2) # user_1, foo_user_11
+        self.assertEqual(len(ret), 2)  # user_1, foo_user_11
 
     def testMaxResultsZero(self):
         ret = self.plugin.enumerateUsers(max_results=0)
@@ -134,12 +134,11 @@ class TestEnumerateUsers(basetestcase.BaseTestCase):
         self.assertEqual(len(ret), 1)
         ret = self.plugin.enumerateUsers(fullname='Not There')
         self.assertEqual(len(ret), 0)
-        
 
-def test_suite( ):
+
+def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestUserManager))
     suite.addTest(makeSuite(TestEnumerateUsers))
     return suite
-        
